==> ted_2.11.orig.tar.gz: Ted-2.11/appFrame/appPaperChooser.h <==
#   ifndef	APP_PAPER_CHOOSER_H
#   define	APP_PAPER_CHOOSER_H

#   include	<appFrame.h>
#   include	<utilPropMask.h>

/************************************************************************/
/*									*/
/*  A paper chooser to be embedded in another window.			*/
/*									*/
/************************************************************************/

typedef struct PaperChooser
    {
    APP_WIDGET		pcFrame;
    APP_WIDGET		pcVerticalColumn;

    AppOptionmenu	pcOptionmenu;
    APP_WIDGET		pcSizeText;

    APP_WIDGET		pcOrientationRow;
    APP_WIDGET		pcPortraitRadio;
    APP_WIDGET		pcLandscapeRadio;

    int			pcCustomPaperSize;
    int			pcSizeChosen;
    int			pcSizeSet;
    int			pcLandscapeChosen;
    int			pcLandscapeSet;

    int			pcSizeOptionCount;
    APP_WIDGET *	pcSizeOptions;
    } PaperChooser;

# define appPaperChooserRetreshMenuWidth( pc ) \
			    appOptionmenuRefreshWidth( &((pc)->pcOptionmenu) )

/************************************************************************/
/*									*/
/*  Routine declarations.						*/
/*									*/
/************************************************************************/

extern void appPaperChooserShowWidthHeight( PaperChooser *	pc,
				const DocumentGeometry *	dg,
				int				unitInt );

extern void appPaperChooserShowSize(	PaperChooser *		pc,
					int			sizeChosen );

extern int appPaperChooserGetSize(	PropertyMask *		pUpdMask,
					PaperChooser *		pc,
					int			unitInt,
					DocumentGeometry *	dg );

extern void appPaperChooserFillMenu(	PaperChooser *		pc,
					const char *		customLabel,
					APP_BUTTON_CALLBACK	callback,
					void *			through );

extern void appPaperChooserAdaptToGeometry( PaperChooser *	pc,
					int			unitType,
					const DocumentGeometry * dg,
					int			set );

extern void appPaperSizeChosen(		APP_WIDGET		w,
					PaperChooser *		pc,
					DocumentGeometry *	dg,
					int			unitType );

extern void appPaperSizeChanged(	PaperChooser *		pc,
					DocumentGeometry *	dg,
					int			unitType );

extern void appMakePaperChooserWidgets(	APP_WIDGET		parent,
					const char *		title,
					PaperChooser *		pc,
					APP_TEXT_ACTIVATE_CALLBACK
								changedCallback,
					void *			through );

extern void appPaperChooserAddOrientationToggles( PaperChooser * pc,
					const char *		portrait,
					const char *		landscape,
					APP_TOGGLE_CALLBACK	callback,
					void *			through );

extern void appPageToolShowOrientation(	PaperChooser *	pc );

extern void appPaperOrientationChosen(	APP_WIDGET		w,
					void *			voidtbcs,
					int *			pChanged,
					PaperChooser *		pc,
					int			unitType,
					DocumentGeometry *	dg );

extern void appInitPaperChooser(	PaperChooser *		pc );
extern void appCleanPaperChooser(	PaperChooser *		pc );

#   endif	/*  APP_PAPER_CHOOSER_H  */

==> ted_2.16.orig.tar.gz: Ted-2.16/appFrame/appPaperChooser.h <==
#   ifndef	APP_PAPER_CHOOSER_H
#   define	APP_PAPER_CHOOSER_H

#   include	<appFrame.h>
#   include	<utilPropMask.h>

/************************************************************************/
/*									*/
/*  A paper chooser to be embedded in another window.			*/
/*									*/
/************************************************************************/

struct PaperChooser;

typedef void (*PaperChooserCallback)(
				struct PaperChooser *		pc,
				void *				through,
				const DocumentGeometry *	dg );

typedef struct PaperChooser
    {
    APP_WIDGET			pcFrame;
    APP_WIDGET			pcVerticalColumn;

    AppOptionmenu		pcOptionmenu;
    APP_WIDGET			pcSizeText;

    APP_WIDGET			pcOrientationRow;
    APP_WIDGET			pcPortraitRadio;
    APP_WIDGET			pcLandscapeRadio;

    int				pcCustomPaperSize;
    int				pcSizeChosen;
    int				pcLandscapeChosen;
    DocumentGeometry		pcGeometryChosen;

    int				pcSizeOptionCount;
    APP_WIDGET *		pcSizeOptions;

    int				pcUnitType;

    PaperChooserCallback	pcCallback;
    void *			pcCallbackThrough;

    int				pcProgrammatic;
    } PaperChooser;

# define appPaperChooserRetreshMenuWidth( pc ) \
			    appOptionmenuRefreshWidth( &((pc)->pcOptionmenu) )

/************************************************************************/
/*									*/
/*  Routine declarations.						*/
/*									*/
/************************************************************************/

extern void appPaperChooserShowSize(	PaperChooser *		pc,
					int			sizeChosen );

extern int appPaperChooserGetSize(	PropertyMask *		pUpdMask,
					PaperChooser *		pc,
					DocumentGeometry *	dg );

extern void appPaperChooserFillMenu(	PaperChooser *		pc,
					const char *		customLabel );

extern void appPaperChooserAdaptToGeometry(
				PaperChooser *			pc,
				const DocumentGeometry *	dg );

extern void appMakePaperChooserWidgets(	APP_WIDGET		parent,
					const char *		title,
					int			unitType,
					PaperChooser *		pc,
					PaperChooserCallback	callback,
					void *			through );

extern void appPaperChooserAddOrientationToggles( PaperChooser * pc,
					const char *		portrait,
					const char *		landscape );

extern void appInitPaperChooser(	PaperChooser *		pc );
extern void appCleanPaperChooser(	PaperChooser *		pc );

#   endif	/*  APP_PAPER_CHOOSER_H  */
